import "./tasks/mendelian.wdl" as mendelian
import "./tasks/two_family_merge.wdl" as two_family_merge
import "./tasks/votes.wdl" as votes

workflow {{ project_name }} {
	File inputSamplesFile
	Array[Array[File]] inputSamples = read_tsv(inputSamplesFile)
	File ref_dir
	File vcf
	String chromo
	String fasta
	String cluster_config
	String disk_size

	scatter (quartet in inputSamples){
		call mendelian.mendelian as LCL5mendelian {
			input:
			child_vcf=quartet[0],
			LCL7_vcf=quartet[2],
			LCL8_vcf=quartet[3],
			LCL7_name=quartet[6],
			LCL8_name=quartet[7],
			child_name=quartet[4],
			ref_dir=ref_dir,
			fasta=fasta,
			cluster_config=cluster_config,
			disk_size=disk_size
		}
		call mendelian.mendelian as LCL6mendelian {
			input:
			child_vcf=quartet[1],
			LCL7_vcf=quartet[2],
			LCL8_vcf=quartet[3],
			LCL7_name=quartet[6],
			LCL8_name=quartet[7],
			child_name=quartet[5],
			ref_dir=ref_dir,
			fasta=fasta,
			cluster_config=cluster_config,
			disk_size=disk_size
		}
		call two_family_merge.two_family_merge as two_family_merge {
			input:
			LCL5_trio_vcf=LCL5mendelian.trio_vcf,
			LCL6_trio_vcf=LCL6mendelian.trio_vcf,
			family_name=quartet[8],
			cluster_config=cluster_config,
			disk_size=disk_size
		}
	}
	call votes.votes as votes {
		input:
		family_mendelian_info=two_family_merge.family_mendelian_info,
		vcf=vcf,
		chromo=chromo,
		cluster_config=cluster_config,
		disk_size=disk_size
	}
}